@@ -6,6 +6,8 @@ import os
 import os.path
 import sys
 
+import traceback
+
 from typing import NoReturn
 from PyQt5 import QtCore, QtGui, QtWidgets
 
@@ -116,19 +118,14 @@ class MyThread(QtCore.QThread):
 
         self.signal_start.emit()
 
-        # if flag_d_info:
-        #     out = func(*arg, d_info=self.d_info)
-        # else:
-        #     out = func(*arg)
-
         try:
             if flag_d_info:
                 out = func(*arg, d_info=self.d_info)
             else:
                 out = func(*arg)
-        except Exception as e:
-            print(e)
-            out = "MISTAKE DURING PROGRAM EXECUTION\n\n"+str(e)
+        except Exception:
+            out = "MISTAKE DURING PROGRAM EXECUTION\n\n" + \
+                str(traceback.format_exc())
         self.output = out
         self.signal_end.emit()
 
